@@ -38,9 +38,15 @@ struct SimplexValues {
 struct SMapValues {
     DataFrame< double >                  predictions;
     DataFrame< double >                  coefficients;
+    DataFrame< double >                  singularValues;
     std::map< std::string, std::string > parameterMap;
 };
 
+struct SVDValues {
+    std::valarray< double > coefficients;
+    std::valarray< double > singularValues;
+};
+
 // Return object for CrossMap() worker function
 struct CrossMapValues {
     DataFrame< double > LibStats;     // mean libsize, rho, RMSE, MAE
